/* Copyright 2022 The ChromiumOS Authors
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */

#ifndef __AP_POWER_HOST_SLEEP_H
#define __AP_POWER_HOST_SLEEP_H

#include <ap_power/ap_power_interface.h>
#include <power_host_sleep.h>

#ifdef CONFIG_AP_PWRSEQ_DRIVER
#include "ap_power/ap_pwrseq.h"
#endif

/*
 * Deferred call to set active mask according to current power state
 */
void ap_power_set_active_wake_mask(void);

/*
 * Get lazy wake masks for the sleep state provided
 *
 * @param state Power state
 * @param mask  Lazy wake mask.
 *
 * @return 0 for success; -EINVAL if power state is not S3/S5/S0ix
 */
#ifndef CONFIG_AP_PWRSEQ_DRIVER
int ap_power_get_lazy_wake_mask(enum power_states_ndsx state,
				host_event_t *mask);
#else
int ap_power_get_lazy_wake_mask(enum ap_pwrseq_state state, host_event_t *mask);
#endif

#if CONFIG_AP_PWRSEQ_S0IX
/* For S0ix path, flag to notify sleep change */
enum ap_power_sleep_type {
	AP_POWER_SLEEP_NONE,
	AP_POWER_SLEEP_SUSPEND,
	AP_POWER_SLEEP_RESUME,
};

/*
 * Reset host sleep state and clean up
 */
void ap_power_reset_host_sleep_state(void);

/*
 * Get current sleep type notified.
 *
 * @return enum ap_power_sleep_type
 */
enum ap_power_sleep_type ap_power_sleep_get_notify(void);

/*
 * Check if the sleep type current power transition indicates is the same
 * as what is notified. If same, means host sleep event notified by AP
 * through Host Command and SLP_S0 are consistent. Process
 * the transition. Otherwise, no action.
 *
 * @param check_state Sleep type which is going to transit to.
 */
void ap_power_sleep_notify_transition(enum ap_power_sleep_type check_state);
#endif /* CONFIG_AP_PWRSEQ_S0IX */

/*
 * Get sleep timeout from host command context
 */
uint16_t host_get_sleep_timeout(void);

/*
 * Set sleep transitions for host command response
 *
 * @param val sleep transitions
 *
 */
void host_set_sleep_transitions(uint32_t val);

#endif /* __AP_PWRSEQ_HOST_SLEEP_H */
